"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const nock_1 = __importDefault(require("nock"));
const LensPlatformClient_1 = __importDefault(require("./LensPlatformClient"));
const LensPlatformClient_test_1 = require("./LensPlatformClient.test");
describe(".business.*", () => {
    const businessId = "businessId";
    const subscriptionId = "test-subscription";
    const lensPlatformClient = new LensPlatformClient_1.default(LensPlatformClient_test_1.minimumOptions);
    it("can call updateBusinessSubscriptionCustomField", async () => {
        (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress)
            .patch(`/businesses/${businessId}/subscriptions/${subscriptionId}/custom-field`)
            .once()
            .reply(200, {
            id: "test-subscription",
            customFields: [
                {
                    name: "test-field",
                    value: "test-value",
                },
            ],
        });
        const subscription = await lensPlatformClient.business.updateBusinessSubscriptionCustomField({
            businessId: "businessId",
            businessSubscriptionId: "test-subscription",
            customField: { name: "test-field", value: "test-value" },
        });
        expect(subscription.customFields).toBeTruthy();
    });
    it("can call previewBusinessSubscriptionSeatsQuantityChange", async () => {
        (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress)
            .post(`/businesses/${businessId}/subscriptions/${subscriptionId}/change/preview`)
            .once()
            .reply(200, {
            balance: 498,
        });
        const preview = await lensPlatformClient.business.previewBusinessSubscriptionSeatsQuantityChange({
            businessId: "businessId",
            businessSubscriptionId: "test-subscription",
            quantity: 4,
        });
        expect(preview.balance).toEqual(498);
    });
});
