"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InvitationService = exports.invitationEntityKinds = void 0;
const Base_1 = require("./Base");
const exceptions_1 = require("./exceptions");
exports.invitationEntityKinds = ["directInvite", "emailInvite", "weblinkInvite"];
/**
 *
 * The class for consuming all `invitation` resources.
 *
 * @remarks
 * This class should be generated using OpenAPI generator in the future.
 *
 * @alpha
 */
class InvitationService extends Base_1.Base {
    /**
     * Get invitation by id
     */
    async getOne({ id, queryString }) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/invitations/${id}${queryString ? `?${queryString}` : ""}`;
        const json = await (0, exceptions_1.throwExpected)(async () => fetch.get(url), {
            404: () => new exceptions_1.NotFoundException(),
        });
        return json;
    }
    /**
     * Get invitation by key
     */
    async getOneByKey({ key }) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/invitations/by-key/${key}`;
        const json = await (0, exceptions_1.throwExpected)(async () => fetch.get(url), {
            404: () => new exceptions_1.NotFoundException(),
        });
        return json;
    }
    /**
     * Get invitations
     */
    async getMany() {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/invitations`;
        const json = await fetch.get(url);
        return json;
    }
    /**
     * Create one invitation
     */
    async createOne(invitation) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/invitations`;
        const json = await (0, exceptions_1.throwExpected)(async () => fetch.post(url, invitation), {
            404: () => new exceptions_1.SpaceNotFoundException(`id: ${invitation.spaceId}`),
            422(e) {
                var _a;
                const msg = (_a = e === null || e === void 0 ? void 0 : e.body.message) !== null && _a !== void 0 ? _a : "";
                if (msg.includes("is already in space")) {
                    return new exceptions_1.UserAlreadyExistsException(invitation.invitedUsername);
                }
                if (msg.includes("pending invitation")) {
                    return new exceptions_1.PendingInvitationException(invitation.invitedUsername);
                }
                if (msg.includes("email missing")) {
                    return new exceptions_1.EmailMissingException();
                }
                return new exceptions_1.PastExpiryException();
            },
        });
        return json;
    }
    /**
     * Update one invitation
     */
    async updateOne(invitation) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/invitations/${invitation.id}`;
        const json = await (0, exceptions_1.throwExpected)(async () => fetch.patch(url, invitation), {
            403(error) {
                var _a, _b, _c;
                const message = (_a = error === null || error === void 0 ? void 0 : error.body) === null || _a === void 0 ? void 0 : _a.message;
                if (typeof message === "string" && message.includes("your email address domain")) {
                    return new exceptions_1.InvalidEmailDomainException((_b = error === null || error === void 0 ? void 0 : error.body) === null || _b === void 0 ? void 0 : _b.message);
                }
                return new exceptions_1.ForbiddenException((_c = error === null || error === void 0 ? void 0 : error.body) === null || _c === void 0 ? void 0 : _c.message);
            },
        });
        return json;
    }
}
exports.InvitationService = InvitationService;
