"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TeamService = exports.teamEntityKinds = void 0;
const Base_1 = require("./Base");
const exceptions_1 = require("./exceptions");
exports.teamEntityKinds = ["Admin", "Normal", "Owner"];
/**
 *
 * The class for consuming all `team` resources.
 *
 * @remarks
 * This class should be generated using OpenAPI generator in the future.
 *
 * @alpha
 */
class TeamService extends Base_1.Base {
    /**
     * Get one team by team id
     */
    async getOne({ id }) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/teams/${id}`;
        const json = await fetch.get(url);
        return json;
    }
    /**
     * Get all teams
     */
    async getMany() {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/teams`;
        const json = await fetch.get(url);
        return json;
    }
    /**
     * Create one team
     */
    async createOne({ team }) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/teams`;
        const json = await fetch.post(url, team);
        return json;
    }
    /**
     * Delete one team by team id
     */
    async deleteOne({ id }) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/teams/${id}`;
        await fetch.delete(url);
    }
    /**
     * Add a user by username to a team by team id
     */
    async addUser({ username, id }) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/teams/${id}/users`;
        const json = await fetch.post(url, { username });
        return json;
    }
    /**
     * Remove a user by username from a team by team id
     */
    async removeUser({ username, id }) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/teams/${id}/users/${username}`;
        const json = await (0, exceptions_1.throwExpected)(async () => fetch.delete(url), {
            404(error) {
                const message = error === null || error === void 0 ? void 0 : error.body.message;
                if (typeof message === "string" && message.includes("Space not found")) {
                    return new exceptions_1.SpaceNotFoundException();
                }
                return new exceptions_1.UserNameNotFoundException(username);
            },
            422: () => new exceptions_1.CantRemoveLastTeamUser(),
        });
        return json;
    }
}
exports.TeamService = TeamService;
