"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InternalServerException = exports.UnprocessableEntityException = exports.BadRequestException = exports.TokenNotFoundException = exports.ForbiddenException = exports.ConflictException = exports.UnauthorizedException = exports.NotFoundException = exports.LensSDKException = void 0;
/**
 * Base class for exceptions
 */
class LensSDKException extends Error {
    constructor(errorCode, message, rawException) {
        super(message);
        this.errorCode = errorCode;
        this.message = message;
        this.rawException = rawException;
        Object.setPrototypeOf(this, LensSDKException.prototype);
        if (Error.captureStackTrace !== undefined) {
            Error.captureStackTrace(this, LensSDKException);
        }
    }
}
exports.LensSDKException = LensSDKException;
class NotFoundException extends LensSDKException {
    constructor(message = "Entity not found", rawException) {
        super(404, message, rawException);
        Object.setPrototypeOf(this, NotFoundException.prototype);
    }
}
exports.NotFoundException = NotFoundException;
class UnauthorizedException extends LensSDKException {
    constructor(message = "Failed to verify authorization token", rawException) {
        super(401, message, rawException);
        Object.setPrototypeOf(this, UnauthorizedException.prototype);
    }
}
exports.UnauthorizedException = UnauthorizedException;
class ConflictException extends LensSDKException {
    constructor(message = "Conflict", rawException) {
        super(409, message, rawException);
        Object.setPrototypeOf(this, UnauthorizedException.prototype);
    }
}
exports.ConflictException = ConflictException;
class ForbiddenException extends LensSDKException {
    constructor(message = "Forbidden", rawException) {
        super(403, message, rawException);
        Object.setPrototypeOf(this, ForbiddenException.prototype);
    }
}
exports.ForbiddenException = ForbiddenException;
class TokenNotFoundException extends LensSDKException {
    constructor(message = "Token not found", rawException) {
        super(500, message, rawException);
        Object.setPrototypeOf(this, TokenNotFoundException.prototype);
    }
}
exports.TokenNotFoundException = TokenNotFoundException;
class BadRequestException extends LensSDKException {
    constructor(message = "Bad request", rawException) {
        super(400, message, rawException);
        Object.setPrototypeOf(this, BadRequestException.prototype);
    }
}
exports.BadRequestException = BadRequestException;
class UnprocessableEntityException extends LensSDKException {
    constructor(message = "Unprocessable entity", rawException) {
        super(422, message, rawException);
        Object.setPrototypeOf(this, UnprocessableEntityException.prototype);
    }
}
exports.UnprocessableEntityException = UnprocessableEntityException;
class InternalServerException extends LensSDKException {
    constructor(message = "Internal server error", rawException) {
        super(500, message, rawException);
        Object.setPrototypeOf(this, InternalServerException.prototype);
    }
}
exports.InternalServerException = InternalServerException;
